pub(crate) fn clock_highlight_type_menu(
ui: &mut Ui,
msgs: &mut Vec<Message>,
clock_highlight_type: ClockHighlightType,
)Expand description
Renders the UI radio options for selecting the clock highlight type.
pub(crate) fn clock_highlight_type_menu(
ui: &mut Ui,
msgs: &mut Vec<Message>,
clock_highlight_type: ClockHighlightType,
)Renders the UI radio options for selecting the clock highlight type.